@@ -1107,6 +1107,28 @@ It returns the current object for chaining, or C<undef> if there was an error, w
 
 Serialisation by L<CBOR|CBOR::XS>, L<Sereal> and L<Storable::Improved> (or the legacy L<Storable>) is supported by this package. To that effect, the following subroutines are implemented: C<FREEZE>, C<THAW>, C<STORABLE_freeze> and C<STORABLE_thaw>
 
+=head1 THREAD SAFETY
+
+This module is thread-safe by design, provided that:
+
+=over 4
+
+=item *
+
+Each thread creates or uses its own C<Module::Generic::File::Mmap> instance.
+
+=item *
+
+Underlying mmap access is managed via L<Cache::FastMmap>, which internally supports safe access via file locks and mmap.
+
+=item *
+
+Thawing and serialization are protected against circular references and duplicated shared state.
+
+=back
+
+No global variables are used, and state-dependent logic is wrapped in thread-safe conditionals using C<HAS_THREADS> and C<lock()>.
+
 =head1 AUTHOR
 
 Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
