@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Scalar.pm
-## Version v1.3.4
-## Copyright(c) 2022 DEGUEST Pte. Ltd.
+## Version v1.4.0
+## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2023/03/12
+## Modified 2025/04/19
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -13,10 +13,12 @@
 package Module::Generic::Scalar;
 BEGIN
 {
+    use v5.26.1;
     use common::sense;
     use warnings;
     use warnings::register;
     use vars qw( $DEBUG $ERROR $ERRORS );
+    use Config;
     use Encode ();
     # So that the user can say $obj->isa( 'Module::Generic::Scalar' ) and it would return true
     # use parent -norequire, qw( Module::Generic::Scalar );
@@ -77,11 +79,18 @@ BEGIN
         },
         fallback => 1,
     );
+    use constant HAS_THREADS => ( $Config{useithreads} && $INC{'threads.pm'} );
+    if( HAS_THREADS )
+    {
+        require threads;
+        import threads;
+    }
     $DEBUG = 0;
     $ERRORS = {};
-    our $VERSION = 'v1.3.4';
+    our $VERSION = 'v1.4.0';
 };
 
+use v5.26.1;
 use strict;
 no warnings 'redefine';
 require Module::Generic::Array;
@@ -341,7 +350,13 @@ sub error
 
         if( !$args->{no_return_null_object} && want( 'OBJECT' ) )
         {
-            require Module::Generic::Null;
+            state $loaded;
+            unless( $loaded )
+            {
+                lock( $loaded ) if( HAS_THREADS );
+                require Module::Generic::Null;
+                $loaded = 1;
+            }
             my $null = Module::Generic::Null->new( $o, { debug => $DEBUG, has_error => 1 });
             rreturn( $null );
         }
@@ -349,7 +364,13 @@ sub error
     }
     if( !$ERRORS->{ $addr } && want( 'OBJECT' ) )
     {
-        require Module::Generic::Null;
+        state $loaded;
+        unless( $loaded )
+        {
+            lock( $loaded ) if( HAS_THREADS );
+            require Module::Generic::Null;
+            $loaded = 1;
+        }
         my $null = Module::Generic::Null->new( $o, { debug => $DEBUG, wants => 'object' });
         rreturn( $null );
     }
@@ -468,7 +489,13 @@ sub object { return( $_[0] ); }
 sub open
 {
     my $self = shift( @_ );
-    require Module::Generic::Scalar::IO;
+    state $loaded;
+    unless( $loaded )
+    {
+        lock( $loaded ) if( HAS_THREADS );
+        require Module::Generic::Scalar::IO;
+        $loaded = 1;
+    }
     my $io = Module::Generic::Scalar::IO->new( $self, @_ ) || 
         return( $self->pass_error( Module::Generic::Scalar::IO->error ) );
     return( $io );
@@ -562,7 +589,13 @@ sub pass_error
     
     if( want( 'OBJECT' ) )
     {
-        require Module::Generic::Null;
+        state $loaded;
+        unless( $loaded )
+        {
+            lock( $loaded ) if( HAS_THREADS );
+            require Module::Generic::Null;
+            $loaded = 1;
+        }
         my $null = Module::Generic::Null->new( $err, { debug => $ERRORS->{ $addr }, has_error => 1 });
         rreturn( $null );
     }
@@ -778,7 +811,13 @@ sub _array
         {
             # We might have need to specify, because I found a race condition where
             # even though the context is object, once in Null, the context became 'code'
-            require Module::Generic::Null;
+            state $loaded;
+            unless( $loaded )
+            {
+                lock( $loaded ) if( HAS_THREADS );
+                require Module::Generic::Null;
+                $loaded = 1;
+            }
             return( Module::Generic::Null->new( wants => 'OBJECT' ) );
         }
         else
@@ -800,7 +839,13 @@ sub _number
         {
             # We might have need to specify, because I found a race condition where
             # even though the context is object, once in Null, the context became 'code'
-            require Module::Generic::Null;
+            state $loaded;
+            unless( $loaded )
+            {
+                lock( $loaded ) if( HAS_THREADS );
+                require Module::Generic::Null;
+                $loaded = 1;
+            }
             return( Module::Generic::Null->new( wants => 'OBJECT' ) );
         }
         else
