@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/SharedMem.pm
-## Version v0.4.2
-## Copyright(c) 2024 DEGUEST Pte. Ltd.
+## Version v0.5.0
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/01/18
-## Modified 2025/03/12
+## Modified 2025/04/19
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -13,6 +13,7 @@
 package Module::Generic::SharedMem;
 BEGIN
 {
+    use v5.26.1;
     use strict;
     use warnings;
     use warnings::register;
@@ -37,6 +38,12 @@ BEGIN
     use constant LOCK_EX        =>  2;
     use constant LOCK_NB        =>  4;
     use constant LOCK_UN        =>  8;
+    use constant HAS_THREADS    => ( $Config{useithreads} && $INC{'threads.pm'} );
+    if( HAS_THREADS )
+    {
+        require threads;
+        import threads;
+    }
     # if( $^O =~ /^(?:Android|cygwin|dos|MSWin32|os2|VMS|riscos)/ )
     # Even better
     $SUPPORTED_RE = qr/IPC\/SysV/;
@@ -119,9 +126,10 @@ EOT
             lock    => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
             'flock' => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
     );
-    our $VERSION = 'v0.4.2';
+    our $VERSION = 'v0.5.0';
 };
 
+use v5.26.1;
 # use strict;
 no warnings 'redefine';
 
@@ -1120,7 +1128,13 @@ sub _str2key
     {
         # my $id = 0;
         # $id += $_ for( unpack( "C*", $key ) );
-        require Digest::SHA;
+        state $loaded;
+        unless( $loaded )
+        {
+            lock( $loaded ) if( HAS_THREADS );
+            require Digest::SHA;
+            $loaded = 1;
+        }
         my $hash = Digest::SHA::sha1_base64( $key );
         my $id = ord( substr( $hash, 0, 1 ) );
         # We use the root as a reliable and stable path.
