@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/SharedMemXS.pm
-## Version v0.2.4
-## Copyright(c) 2024 DEGUEST Pte. Ltd.
+## Version v0.3.0
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 1970/01/01
-## Modified 2025/03/12
+## Modified 2025/04/19
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -13,6 +13,7 @@
 package Module::Generic::SharedMemXS;
 BEGIN
 {
+    use v5.26.1;
     use strict;
     use warnings;
     use warnings::register;
@@ -37,6 +38,12 @@ BEGIN
     use constant LOCK_EX        =>  2;
     use constant LOCK_NB        =>  4;
     use constant LOCK_UN        =>  8;
+    use constant HAS_THREADS    => ( $Config{useithreads} && $INC{'threads.pm'} );
+    if( HAS_THREADS )
+    {
+        require threads;
+        import threads;
+    }
     $SUPPORTED_RE = qr/IPC\/SysV/;
     if( $Config{extensions} =~ /$SUPPORTED_RE/ && 
         $^O !~ /^(?:Android|dos|MSWin32|os2|VMS|riscos)/i &&
@@ -111,9 +118,10 @@ EOT
             lock    => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
             'flock' => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
     );
-    our $VERSION = 'v0.2.4';
+    our $VERSION = 'v0.3.0';
 };
 
+use v5.26.1;
 use strict;
 use warnings;
 # no warnings 'redefine';
@@ -1209,7 +1217,13 @@ sub _str2key
     {
         # my $id = 0;
         # $id += $_ for( unpack( "C*", $key ) );
-        require Digest::SHA;
+        state $loaded;
+        unless( $loaded )
+        {
+            lock( $loaded ) if( HAS_THREADS );
+            require Digest::SHA;
+            $loaded = 1;
+        }
         my $hash = Digest::SHA::sha1_base64( $key );
         my $id = ord( substr( $hash, 0, 1 ) );
         # We use the root as a reliable and stable path.
@@ -1450,7 +1464,7 @@ Module::Generic::SharedMemXS - Shared Memory Manipulation with XS API
 
 =head1 VERSION
 
-    v0.2.4
+    v0.3.0
 
 =head1 DESCRIPTION
 
@@ -1861,6 +1875,26 @@ It returns the current object for chaining, or C<undef> if there was an error, w
 
 Serialisation by L<CBOR|CBOR::XS>, L<Sereal> and L<Storable::Improved> (or the legacy L<Storable>) is supported by this package. To that effect, the following subroutines are implemented: C<FREEZE>, C<THAW>, C<STORABLE_freeze> and C<STORABLE_thaw>
 
+=head1 PROCESS CLEANUP SAFETY
+
+This module attempts to automatically clean up shared memory and semaphore resources using an C<END> block. However, note that:
+
+=over 4
+
+=item *
+
+In multi-threaded programs, C<END> blocks may not execute for all threads.
+
+=item *
+
+If multiple processes share a memory segment, only the original owner should call C<remove()> or rely on auto-cleanup.
+
+=item *
+
+For best results, call C<remove()> manually if your lifecycle logic requires guaranteed cleanup.
+
+=back
+
 =head1 AUTHOR
 
 Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
